Copula.Hconfig_gaussian_density: Gaussian copula density for each H-configuration.

View source: R/EM_functions.R

Copula.Hconfig_gaussian_densityR Documentation

Gaussian copula density for each H-configuration.

Description

Gaussian copula density for each H-configuration.

Usage

Copula.Hconfig_gaussian_density(Hconfig, F0Mat, F1Mat, R)

Arguments

Hconfig

A list of all possible combination of H_0 and H_1 hypotheses generated by the GetHconfig() function.

F0Mat

a matrix containing the evaluation of the marginal cdf under H_0 at each items, each column corresponding to a p-value serie.

F1Mat

a matrix containing the evaluation of the marginal cdf under H_1 at each items, each column corresponding to a p-value serie.

R

the correlation matrix.

Value

A matrix containing the evaluation of the Gaussian density function for each H-configuration in columns.


qch documentation built on Feb. 16, 2026, 5:07 p.m.