EM_calibration_gaussian: EM calibration in the case of the Gaussian copula (unsigned)

View source: R/EM_functions.R

EM_calibration_gaussianR Documentation

EM calibration in the case of the Gaussian copula (unsigned)

Description

EM calibration in the case of the Gaussian copula (unsigned)

Usage

EM_calibration_gaussian(
  Hconfig,
  F0Mat,
  F1Mat,
  fHconfig,
  R.init,
  Prior.init,
  Precision = 1e-06
)

Arguments

Hconfig

A list of all possible combination of H_0 and H_1 hypotheses generated by the GetHconfig() function.

F0Mat

a matrix containing the evaluation of the marginal cdf under H_0 at each items, each column corresponding to a p-value serie.

F1Mat

a matrix containing the evaluation of the marginal cdf under H_1 at each items, each column corresponding to a p-value serie.

fHconfig

a matrix containing H-config densities evaluated at each items, each column corresponding to a configurations.

R.init

the initialization of the correlation matrix of the Gaussian copula parameter.

Prior.init

the initialization of prior probabilities for each of the H-configurations.

Precision

Precision for the stop criterion. (Default is 1e-6)

Value

A list with the following elements:

priorHconfig vector of estimated prior probabilities for each of the H-configurations.
Rcopula the estimated correlation matrix of the Gaussian copula.

qch documentation built on Feb. 16, 2026, 5:07 p.m.