EM_calibration_gaussian_memory: EM calibration in the case of the Gaussian copula (unsigned)...

View source: R/EM_functions.R

EM_calibration_gaussian_memoryR Documentation

EM calibration in the case of the Gaussian copula (unsigned) with memory management

Description

EM calibration in the case of the Gaussian copula (unsigned) with memory management

Usage

EM_calibration_gaussian_memory(
  Logf0Mat,
  Logf1Mat,
  F0Mat,
  F1Mat,
  Prior.init,
  R.init,
  Hconfig,
  Precision = 1e-06,
  threads_nb
)

Arguments

Logf0Mat

a matrix containing the \log(f_0(x^i_q))

Logf1Mat

a matrix containing the \log(f_1(x^i_q))

F0Mat

a matrix containing the evaluation of the marginal cdf under H_0 at each items, each column corresponding to a p-value serie.

F1Mat

a matrix containing the evaluation of the marginal cdf under H_1 at each items, each column corresponding to a p-value serie.

Prior.init

the initialization of prior probabilities for each of the H-configurations.

R.init

the initialization of the correlation matrix of the gaussian copula parameter.

Hconfig

A list of all possible combination of H_0 and H_1 hypotheses generated by the GetHconfig() function.

Precision

Precision for the stop criterion. (Default is 1e-6)

threads_nb

The number of threads to use.

Value

A list with the following elements:

priorHconfig vector of estimated prior probabilities for each of the H-configurations.
Rcopula the estimated correlation matrix of the Gaussian copula.

qch documentation built on Feb. 16, 2026, 5:07 p.m.