Learn R Programming

qch (version 2.1.2)

EM_calibration_indep: EM calibration in the case of conditional independence

Description

EM calibration in the case of conditional independence

Usage

EM_calibration_indep(fHconfig, Prior.init, Precision = 1e-06)

Value

a vector of estimated prior probabilities for each of the H-configurations.

Arguments

fHconfig

a matrix containing config densities evaluated at each items, each column corresponding to a configurations.

Prior.init

the initialization of prior probabilities for each of the H-configurations.

Precision

Precision for the stop criterion. (Default is 1e-6)