EM_calibration_indep_memory: EM calibration in the case of conditional independence with...

View source: R/EM_functions.R

EM_calibration_indep_memoryR Documentation

EM calibration in the case of conditional independence with memory management (unsigned)

Description

EM calibration in the case of conditional independence with memory management (unsigned)

Usage

EM_calibration_indep_memory(
  Logf0Mat,
  Logf1Mat,
  Prior.init,
  Hconfig,
  Precision = 1e-06,
  threads_nb
)

Arguments

Logf0Mat

a matrix containing the \log(f_0(x^i_q))

Logf1Mat

a matrix containing the \log(f_1(x^i_q))

Prior.init

the initialization of prior probabilities for each of the H-configurations.

Hconfig

A list of all possible combination of H_0 and H_1 hypotheses generated by the GetHconfig() function.

Precision

Precision for the stop criterion. (Default is 1e-6)

threads_nb

The number of threads to use.

Value

a vector of estimated prior probabilities for each of the H-configurations.


qch documentation built on Feb. 16, 2026, 5:07 p.m.