PvalSets_cor: Synthetic example to illustrate the main qch functions using...

PvalSets_corR Documentation

Synthetic example to illustrate the main qch functions using Gaussian copula

Description

PvalSets_cor is a data.frame with 10,000 rows and 3 columns. Each row corresponds to an item, columns Pval1 and Pval2 each correspond to a test serie over the items, and column 'Class' provides the truth, i.e. if item i belongs to class 1 then the H_0 hypothesis is true for the 2 tests, if item i belongs to class 2 (resp. 3) then the H_0 hypothesis is true for the first (resp. second) test only, and if item i belongs to class 4 then both H0 hypotheses are false (for the first and the second test). The correlation between the two pvalues series within each class is 0.3.

Usage

PvalSets_cor

Format

A data.frame


qch documentation built on Feb. 16, 2026, 5:07 p.m.