R.MLE.check: Check the Gaussian copula correlation matrix Maximum...

View source: R/EM_functions.R

R.MLE.checkR Documentation

Check the Gaussian copula correlation matrix Maximum Likelihood estimator

Description

Check the Gaussian copula correlation matrix Maximum Likelihood estimator

Usage

R.MLE.check(R)

Arguments

R

Estimate of the correlation matrix.

Value

Estimate of the correlation matrix.


qch documentation built on Feb. 16, 2026, 5:07 p.m.