| Copula.Hconfig_gaussian_density | R Documentation |
Gaussian copula density for each H-configuration.
Copula.Hconfig_gaussian_density(Hconfig, F0Mat, F1Mat, R)
Hconfig |
A list of all possible combination of |
F0Mat |
a matrix containing the evaluation of the marginal cdf under |
F1Mat |
a matrix containing the evaluation of the marginal cdf under |
R |
the correlation matrix. |
A matrix containing the evaluation of the Gaussian density function for each H-configuration in columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.