| EM_calibration_gaussian | R Documentation |
EM calibration in the case of the Gaussian copula (unsigned)
EM_calibration_gaussian(
Hconfig,
F0Mat,
F1Mat,
fHconfig,
R.init,
Prior.init,
Precision = 1e-06
)
Hconfig |
A list of all possible combination of |
F0Mat |
a matrix containing the evaluation of the marginal cdf under |
F1Mat |
a matrix containing the evaluation of the marginal cdf under |
fHconfig |
a matrix containing H-config densities evaluated at each items, each column corresponding to a configurations. |
R.init |
the initialization of the correlation matrix of the Gaussian copula parameter. |
Prior.init |
the initialization of prior probabilities for each of the H-configurations. |
Precision |
Precision for the stop criterion. (Default is 1e-6) |
A list with the following elements:
priorHconfig | vector of estimated prior probabilities for each of the H-configurations. |
Rcopula | the estimated correlation matrix of the Gaussian copula. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.