EM calibration in the case of the Gaussian copula (unsigned)
EM_calibration_gaussian(
Hconfig,
F0Mat,
F1Mat,
fHconfig,
R.init,
Prior.init,
Precision = 1e-06
)A list with the following elements:
priorHconfig | vector of estimated prior probabilities for each of the H-configurations. |
Rcopula | the estimated correlation matrix of the Gaussian copula. |
A list of all possible combination of \(H_0\) and \(H_1\) hypotheses generated by the GetHconfig() function.
a matrix containing the evaluation of the marginal cdf under \(H_0\) at each items, each column corresponding to a p-value serie.
a matrix containing the evaluation of the marginal cdf under \(H_1\) at each items, each column corresponding to a p-value serie.
a matrix containing H-config densities evaluated at each items, each column corresponding to a configurations.
the initialization of the correlation matrix of the Gaussian copula parameter.
the initialization of prior probabilities for each of the H-configurations.
Precision for the stop criterion. (Default is 1e-6)