| EM_calibration_gaussian_memory | R Documentation |
EM calibration in the case of the Gaussian copula (unsigned) with memory management
EM_calibration_gaussian_memory(
Logf0Mat,
Logf1Mat,
F0Mat,
F1Mat,
Prior.init,
R.init,
Hconfig,
Precision = 1e-06,
threads_nb
)
Logf0Mat |
a matrix containing the |
Logf1Mat |
a matrix containing the |
F0Mat |
a matrix containing the evaluation of the marginal cdf under |
F1Mat |
a matrix containing the evaluation of the marginal cdf under |
Prior.init |
the initialization of prior probabilities for each of the H-configurations. |
R.init |
the initialization of the correlation matrix of the gaussian copula parameter. |
Hconfig |
A list of all possible combination of |
Precision |
Precision for the stop criterion. (Default is 1e-6) |
threads_nb |
The number of threads to use. |
A list with the following elements:
priorHconfig | vector of estimated prior probabilities for each of the H-configurations. |
Rcopula | the estimated correlation matrix of the Gaussian copula. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.