EM calibration in the case of the Gaussian copula (unsigned) with memory management
EM_calibration_gaussian_memory(
Logf0Mat,
Logf1Mat,
F0Mat,
F1Mat,
Prior.init,
R.init,
Hconfig,
Precision = 1e-06,
threads_nb
)A list with the following elements:
priorHconfig | vector of estimated prior probabilities for each of the H-configurations. |
Rcopula | the estimated correlation matrix of the Gaussian copula. |
a matrix containing the \(\log(f_0(x^i_q))\)
a matrix containing the \(\log(f_1(x^i_q))\)
a matrix containing the evaluation of the marginal cdf under \(H_0\) at each items, each column corresponding to a p-value serie.
a matrix containing the evaluation of the marginal cdf under \(H_1\) at each items, each column corresponding to a p-value serie.
the initialization of prior probabilities for each of the H-configurations.
the initialization of the correlation matrix of the gaussian copula parameter.
A list of all possible combination of \(H_0\) and \(H_1\) hypotheses generated by the GetHconfig() function.
Precision for the stop criterion. (Default is 1e-6)
The number of threads to use.