EM calibration in the case of conditional independence
EM_calibration_indep(fHconfig, Prior.init, Precision = 1e-06)a vector of estimated prior probabilities for each of the H-configurations.
a matrix containing config densities evaluated at each items, each column corresponding to a configurations.
the initialization of prior probabilities for each of the H-configurations.
Precision for the stop criterion. (Default is 1e-6)